==> jc-1.4.0.tar.gz: gnu/java/io/Base64InputStream.h <==
// public class gnu.java.io.Base64InputStream

// class file dependencies
// @dep_class c67c8ea1f6008fb gnu_java_io_Base64InputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_java_io_Base64InputStream_H_
#define _JC_gnu_java_io_Base64InputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_io_Base64InputStream$sub_refs	_jc_gnu_java_io_Base64InputStream$sub_refs;
typedef struct _jc_gnu_java_io_Base64InputStream$sub_nonrefs	_jc_gnu_java_io_Base64InputStream$sub_nonrefs;
typedef struct _jc_gnu_java_io_Base64InputStream$refs	_jc_gnu_java_io_Base64InputStream$refs;
typedef struct _jc_gnu_java_io_Base64InputStream$nonrefs	_jc_gnu_java_io_Base64InputStream$nonrefs;
typedef struct _jc_gnu_java_io_Base64InputStream$object	_jc_gnu_java_io_Base64InputStream$object;

typedef struct _jc_gnu_java_io_Base64InputStream$fields_struct	_jc_gnu_java_io_Base64InputStream$fields_struct;
typedef const struct _jc_gnu_java_io_Base64InputStream$vmethods	_jc_gnu_java_io_Base64InputStream$vmethods;
typedef const struct _jc_gnu_java_io_Base64InputStream$vtable	_jc_gnu_java_io_Base64InputStream$vtable;
typedef const struct _jc_gnu_java_io_Base64InputStream$vtype	_jc_gnu_java_io_Base64InputStream$vtype;

// Class fields structure
struct _jc_gnu_java_io_Base64InputStream$fields_struct {
	struct _jc_java_lang_String$object	*BASE__5f64;
	jchar	BASE__5f64__5fPAD;
};
extern _jc_gnu_java_io_Base64InputStream$fields_struct _jc_gnu_java_io_Base64InputStream$class_fields;

// Constructors
extern void _jc_gnu_java_io_Base64InputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern jint _jc_gnu_java_io_Base64InputStream$method$available$81975cc608605037(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *);
extern void _jc_gnu_java_io_Base64InputStream$method$mark$422af117ab27d9db(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, jint);
extern jboolean _jc_gnu_java_io_Base64InputStream$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *);
extern jint _jc_gnu_java_io_Base64InputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *);
extern jint _jc_gnu_java_io_Base64InputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_gnu_java_io_Base64InputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *);
extern jlong _jc_gnu_java_io_Base64InputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, jlong);
extern void _jc_gnu_java_io_Base64InputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$skip$4e431136b5c4614a;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern _jc_byte_array *_jc_gnu_java_io_Base64InputStream$method$decode$0faa97767d28692c(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_java_io_Base64InputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *);
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, jint);
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *);
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, jlong);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *);
};

// Vtable
struct _jc_gnu_java_io_Base64InputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_io_Base64InputStream$vmethods	gnu_java_io_Base64InputStream;
};

// Vtype
struct _jc_gnu_java_io_Base64InputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_io_Base64InputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_io_Base64InputStream$sub_refs {
	_jc_byte_array	*one;
};

// Reference instance fields (object)
struct _jc_gnu_java_io_Base64InputStream$refs {
    _jc_gnu_java_io_Base64InputStream$sub_refs	gnu_java_io_Base64InputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_io_Base64InputStream$sub_nonrefs {
	jint	state;
	jint	temp;
	jboolean	eof;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_io_Base64InputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_io_Base64InputStream$sub_nonrefs	gnu_java_io_Base64InputStream;
};

// Object instance structure
struct _jc_gnu_java_io_Base64InputStream$object {
	_jc_gnu_java_io_Base64InputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_io_Base64InputStream$vtype	*vtype;
	_jc_gnu_java_io_Base64InputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_io_Base64InputStream$vtype _jc_gnu_java_io_Base64InputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_io_Base64InputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_io_Base64InputStream$class_object;

#endif	/* _JC_gnu_java_io_Base64InputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/io/Base64InputStream.h <==
// public class gnu.java.io.Base64InputStream

// class file dependencies
// @dep_class c67c8ea1f6008fb gnu_java_io_Base64InputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_java_io_Base64InputStream_H_
#define _JC_gnu_java_io_Base64InputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_io_Base64InputStream$sub_refs	_jc_gnu_java_io_Base64InputStream$sub_refs;
typedef struct _jc_gnu_java_io_Base64InputStream$sub_nonrefs	_jc_gnu_java_io_Base64InputStream$sub_nonrefs;
typedef struct _jc_gnu_java_io_Base64InputStream$refs	_jc_gnu_java_io_Base64InputStream$refs;
typedef struct _jc_gnu_java_io_Base64InputStream$nonrefs	_jc_gnu_java_io_Base64InputStream$nonrefs;
typedef struct _jc_gnu_java_io_Base64InputStream$object	_jc_gnu_java_io_Base64InputStream$object;

typedef struct _jc_gnu_java_io_Base64InputStream$fields_struct	_jc_gnu_java_io_Base64InputStream$fields_struct;
typedef const struct _jc_gnu_java_io_Base64InputStream$vmethods	_jc_gnu_java_io_Base64InputStream$vmethods;
typedef const struct _jc_gnu_java_io_Base64InputStream$vtable	_jc_gnu_java_io_Base64InputStream$vtable;
typedef const struct _jc_gnu_java_io_Base64InputStream$vtype	_jc_gnu_java_io_Base64InputStream$vtype;

// Class fields structure
struct _jc_gnu_java_io_Base64InputStream$fields_struct {
	struct _jc_java_lang_String$object	*BASE__5f64;
	jchar	BASE__5f64__5fPAD;
};
extern _jc_gnu_java_io_Base64InputStream$fields_struct _jc_gnu_java_io_Base64InputStream$class_fields;

// Constructors
extern void _jc_gnu_java_io_Base64InputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_io_Base64InputStream$method$available$81975cc608605037(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_io_Base64InputStream$method$mark$422af117ab27d9db(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_io_Base64InputStream$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_io_Base64InputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_io_Base64InputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_io_Base64InputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *) _JC_JCNI_ATTR;
extern jlong _jc_gnu_java_io_Base64InputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, jlong) _JC_JCNI_ATTR;
extern void _jc_gnu_java_io_Base64InputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$skip$4e431136b5c4614a;
extern _jc_method _jc_gnu_java_io_Base64InputStream$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern _jc_byte_array *_jc_gnu_java_io_Base64InputStream$method$decode$0faa97767d28692c(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_io_Base64InputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *) _JC_JCNI_ATTR;
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *) _JC_JCNI_ATTR;
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *, jlong) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_io_Base64InputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_io_Base64InputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_io_Base64InputStream$vmethods	gnu_java_io_Base64InputStream;
};

// Vtype
struct _jc_gnu_java_io_Base64InputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_io_Base64InputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_io_Base64InputStream$sub_refs {
	_jc_byte_array	*one;
};

// Reference instance fields (object)
struct _jc_gnu_java_io_Base64InputStream$refs {
    _jc_gnu_java_io_Base64InputStream$sub_refs	gnu_java_io_Base64InputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_io_Base64InputStream$sub_nonrefs {
	jint	state;
	jint	temp;
	jboolean	eof;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_io_Base64InputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_io_Base64InputStream$sub_nonrefs	gnu_java_io_Base64InputStream;
};

// Object instance structure
struct _jc_gnu_java_io_Base64InputStream$object {
	_jc_gnu_java_io_Base64InputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_io_Base64InputStream$vtype	*vtype;
	_jc_gnu_java_io_Base64InputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_io_Base64InputStream$vtype _jc_gnu_java_io_Base64InputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_io_Base64InputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_io_Base64InputStream$class_object;

#endif	/* _JC_gnu_java_io_Base64InputStream_H_ */
